@@ -3,15 +3,17 @@ package Catmandu::Importer::DBI;
 use Catmandu::Sane;
 use DBI;
 use Moo;
+use MooX::Aliases;
+use namespace::clean;
 
-our $VERSION = '0.0702';
+our $VERSION = '0.08';
 
 with 'Catmandu::Importer';
 
-has dsn => (is => 'ro', required => 1);
-has user     => (is => 'ro');
-has password => (is => 'ro');
-has query    => (is => 'ro', required => 1);
+has data_source => (is => 'ro', required => 1, alias => 'dsn');
+has username    => (is => 'ro', alias    => 'user');
+has password    => (is => 'ro', alias    => 'pass');
+has query       => (is => 'ro', required => 1);
 has dbh =>
     (is => 'ro', init_arg => undef, lazy => 1, builder => '_build_dbh',);
 has sth =>
@@ -19,7 +21,20 @@ has sth =>
 
 sub _build_dbh {
     my $self = $_[0];
-    DBI->connect($self->dsn, $self->user, $self->password);
+    DBI->connect(
+        $self->dsn,
+        $self->user,
+        $self->password,
+        {
+            AutoCommit                       => 1,
+            RaiseError                       => 1,
+            mysql_auto_reconnect             => 1,
+            mysql_enable_utf8                => 1,
+            pg_utf8_strings                  => 1,
+            sqlite_use_immediate_transaction => 1,
+            sqlite_unicode                   => 1,
+        }
+    );
 }
 
 sub _build_sth {
@@ -47,6 +62,10 @@ sub DESTROY {
 
 Catmandu::Importer::DBI - Catmandu module to import data from any DBI source
 
+=head1 LIMITATIONS
+
+Text columns are assumed to be utf-8.
+
 =head1 SYNOPSIS
 
  # From the command line 
