@@ -5,9 +5,10 @@ use Catmandu::Util qw(require_package);
 use DBI;
 use Catmandu::Store::DBI::Bag;
 use Moo;
+use MooX::Aliases;
 use namespace::clean;
 
-our $VERSION = "0.0702";
+our $VERSION = "0.08";
 
 with 'Catmandu::Store';
 with 'Catmandu::Transactional';
@@ -15,19 +16,21 @@ with 'Catmandu::Transactional';
 has data_source => (
     is       => 'ro',
     required => 1,
+    alias    => 'dsn',
     trigger  => sub {
         my $ds = $_[0]->{data_source};
         $ds = $ds =~ /^DBI:/i ? $ds : "DBI:$ds";
         $_[0]->{data_source} = $ds;
     },
 );
-has username => (is => 'ro', default => sub {''});
-has password => (is => 'ro', default => sub {''});
+has username => (is => 'ro', default => sub {''}, alias => 'user');
+has password => (is => 'ro', default => sub {''}, alias => 'pass');
 has timeout => (is => 'ro', predicate => 1);
 has reconnect_after_timeout => (is => 'ro');
+has default_order           => (is => 'ro', default => sub {'ID'});
 has handler                 => (is => 'lazy');
-has _in_transaction         => (is => 'rw', writer => '_set_in_transaction',);
-has _connect_time           => (is => 'rw', writer => '_set_connect_time');
+has _in_transaction => (is => 'rw', writer => '_set_in_transaction',);
+has _connect_time   => (is => 'rw', writer => '_set_connect_time');
 has _dbh => (is => 'lazy', builder => '_build_dbh', writer => '_set_dbh',);
 
 sub handler_namespace {
@@ -141,7 +144,7 @@ __END__
 
 =head1 NAME
 
-Catmandu::Store::DBI - A Catmandu::Store plugin for DBI based interfaces
+Catmandu::Store::DBI - A Catmandu::Store backed by DBI
 
 =head1 VERSION
 
@@ -208,6 +211,11 @@ create them automatically. See  "DATABASE CONFIGURATION" below.
 DO NOT USE Catmandu::Store::DBI on an existing database! Tables and
 data can be deleted and changed.
 
+=head1 LIMITATIONS
+
+Currently only MySQL, Postgres and SQLite are supported. Text columns are also
+assumed to be utf-8.
+
 =head1 CONFIGURATION
 
 =over
@@ -248,6 +256,13 @@ See TIMEOUTS below for more information.
 Optional. When a timeout is reached, Catmandu reconnects to the database. By
 default set to '0'
 
+=item default_order
+
+Optional. Default the default sorting of results when returning an iterator.
+Choose 'ID' to order on the configured identifier field, 'NONE' to skip all
+ordering, or "$field" where $field is the name of a table column. By default
+set to 'ID'.
+
 =back
 
 =head1 DATABASE CONFIGURATION
@@ -289,6 +304,18 @@ See L<Catmandu::Store::DBI::Bag> for more information.
 
 =item binary
 
+=item datetime
+
+Only MySQL, PostgreSQL
+
+=item datetime_milli
+
+Only MySQL, PostgreSQL
+
+=item json
+
+Only PostgreSQL
+
 =back
 
 =head2 Column options
@@ -301,7 +328,7 @@ Name of the table column if it differs from the key in your data.
 
 =item array
 
-Boolean option, default is C<0>. Note that this options is only supported for PostgreSQL.
+Boolean option, default is C<0>. Note that this is only supported for PostgreSQL.
 
 =item unique
 
