@@ -5,7 +5,7 @@ use Moo;
 use Catmandu::Store::DBI::Iterator;
 use namespace::clean;
 
-our $VERSION = "0.0702";
+our $VERSION = "0.08";
 
 my $default_mapping = {
     _id => {
@@ -19,6 +19,7 @@ my $default_mapping = {
 };
 
 has mapping => (is => 'ro', default => sub {+{%$default_mapping}},);
+has default_order => (is => 'ro');
 
 has _iterator => (
     is      => 'ro',
@@ -176,6 +177,15 @@ sub _data_to_row {
     $row;
 }
 
+sub _quote_id {
+    $_[0]->store->dbh->quote_identifier($_[1]);
+}
+
+sub _max_limit {    # should be plenty large
+    use bigint;
+    state $max_limit = 2**63 - 1;
+}
+
 =head1 NAME
 
 Catmandu::Store::DBI::Bag - implementation of a Catmandu::Bag for DBI
